"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Category:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CategoryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Category.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CATEGORY_UNSPECIFIED: _Category.ValueType  # 0
    """"""
    CATEGORY_ONE: _Category.ValueType  # 1
    """"""
    CATEGORY_TWO: _Category.ValueType  # 2
    """"""
    CATEGORY_THREE: _Category.ValueType  # 3
    """"""
    CATEGORY_FOUR: _Category.ValueType  # 4
    """"""

class Category(_Category, metaclass=_CategoryEnumTypeWrapper):
    """"""

CATEGORY_UNSPECIFIED: Category.ValueType  # 0
""""""
CATEGORY_ONE: Category.ValueType  # 1
""""""
CATEGORY_TWO: Category.ValueType  # 2
""""""
CATEGORY_THREE: Category.ValueType  # 3
""""""
CATEGORY_FOUR: Category.ValueType  # 4
""""""
global___Category = Category

class _ErrorReason:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ErrorReasonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ErrorReason.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PROBE_UNSPECIFIED: _ErrorReason.ValueType  # 0
    """"""
    PROBE_CATEGORY_NOTFOUND: _ErrorReason.ValueType  # 1
    """"""

class ErrorReason(_ErrorReason, metaclass=_ErrorReasonEnumTypeWrapper):
    """Deprecated"""

PROBE_UNSPECIFIED: ErrorReason.ValueType  # 0
""""""
PROBE_CATEGORY_NOTFOUND: ErrorReason.ValueType  # 1
""""""
global___ErrorReason = ErrorReason

@typing_extensions.final
class CodeReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ID1_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_S_FIELD_NUMBER: builtins.int
    id: builtins.str
    """"""
    id1: builtins.str
    """"""
    code: builtins.int
    """"""
    message_s: builtins.str
    """"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        id1: builtins.str = ...,
        code: builtins.int = ...,
        message_s: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "id", b"id", "id1", b"id1", "message_s", b"message_s"]) -> None: ...

global___CodeReply = CodeReply

@typing_extensions.final
class CodeReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code"]) -> None: ...

global___CodeReq = CodeReq

@typing_extensions.final
class CreateTopic(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___CreateTopic = CreateTopic

@typing_extensions.final
class CreatTask(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    task: builtins.str
    """"""
    def __init__(
        self,
        *,
        task: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["task", b"task"]) -> None: ...

global___CreatTask = CreatTask

@typing_extensions.final
class DynamicMessageUpdate(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BODY_FIELD_NUMBER: builtins.int
    @property
    def body(self) -> global___SimpleMessage:
        """"""
    def __init__(
        self,
        *,
        body: global___SimpleMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["body", b"body"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["body", b"body"]) -> None: ...

global___DynamicMessageUpdate = DynamicMessageUpdate

@typing_extensions.final
class Embedded(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MapStringValEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MapErrorValEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___ErrorMessage: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___ErrorMessage | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BOOL_VAL_FIELD_NUMBER: builtins.int
    INT32_VAL_FIELD_NUMBER: builtins.int
    INT64_VAL_FIELD_NUMBER: builtins.int
    FLOAT_VAL_FIELD_NUMBER: builtins.int
    DOUBLE_VAL_FIELD_NUMBER: builtins.int
    STRING_VAL_FIELD_NUMBER: builtins.int
    REPEATED_BOOL_VAL_FIELD_NUMBER: builtins.int
    REPEATED_INT32_VAL_FIELD_NUMBER: builtins.int
    REPEATED_INT64_VAL_FIELD_NUMBER: builtins.int
    REPEATED_FLOAT_VAL_FIELD_NUMBER: builtins.int
    REPEATED_DOUBLE_VAL_FIELD_NUMBER: builtins.int
    REPEATED_STRING_VAL_FIELD_NUMBER: builtins.int
    MAP_STRING_VAL_FIELD_NUMBER: builtins.int
    MAP_ERROR_VAL_FIELD_NUMBER: builtins.int
    bool_val: builtins.bool
    """"""
    int32_val: builtins.int
    """"""
    int64_val: builtins.int
    """"""
    float_val: builtins.float
    """"""
    double_val: builtins.float
    """"""
    string_val: builtins.str
    """"""
    @property
    def repeated_bool_val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bool]:
        """"""
    @property
    def repeated_int32_val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """"""
    @property
    def repeated_int64_val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """"""
    @property
    def repeated_float_val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """"""
    @property
    def repeated_double_val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """"""
    @property
    def repeated_string_val(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def map_string_val(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    @property
    def map_error_val(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___ErrorMessage]:
        """"""
    def __init__(
        self,
        *,
        bool_val: builtins.bool = ...,
        int32_val: builtins.int = ...,
        int64_val: builtins.int = ...,
        float_val: builtins.float = ...,
        double_val: builtins.float = ...,
        string_val: builtins.str = ...,
        repeated_bool_val: collections.abc.Iterable[builtins.bool] | None = ...,
        repeated_int32_val: collections.abc.Iterable[builtins.int] | None = ...,
        repeated_int64_val: collections.abc.Iterable[builtins.int] | None = ...,
        repeated_float_val: collections.abc.Iterable[builtins.float] | None = ...,
        repeated_double_val: collections.abc.Iterable[builtins.float] | None = ...,
        repeated_string_val: collections.abc.Iterable[builtins.str] | None = ...,
        map_string_val: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        map_error_val: collections.abc.Mapping[builtins.str, global___ErrorMessage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bool_val", b"bool_val", "double_val", b"double_val", "float_val", b"float_val", "int32_val", b"int32_val", "int64_val", b"int64_val", "map_error_val", b"map_error_val", "map_string_val", b"map_string_val", "repeated_bool_val", b"repeated_bool_val", "repeated_double_val", b"repeated_double_val", "repeated_float_val", b"repeated_float_val", "repeated_int32_val", b"repeated_int32_val", "repeated_int64_val", b"repeated_int64_val", "repeated_string_val", b"repeated_string_val", "string_val", b"string_val"]) -> None: ...

global___Embedded = Embedded

@typing_extensions.final
class ErrorMessage(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""
    reason: builtins.str
    """"""
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        reason: builtins.str = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "message", b"message", "reason", b"reason"]) -> None: ...

global___ErrorMessage = ErrorMessage

@typing_extensions.final
class ProbeReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    content: builtins.str
    """"""
    timestamp: builtins.int
    """"""
    def __init__(
        self,
        *,
        content: builtins.str = ...,
        timestamp: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "timestamp", b"timestamp"]) -> None: ...

global___ProbeReply = ProbeReply

@typing_extensions.final
class ProbeReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    BUVID_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    buvid: builtins.str
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        buvid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buvid", b"buvid", "mid", b"mid"]) -> None: ...

global___ProbeReq = ProbeReq

@typing_extensions.final
class ProbeStreamReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEQUENCE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    sequence: builtins.int
    """"""
    timestamp: builtins.int
    """"""
    content: builtins.str
    """"""
    def __init__(
        self,
        *,
        sequence: builtins.int = ...,
        timestamp: builtins.int = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "sequence", b"sequence", "timestamp", b"timestamp"]) -> None: ...

global___ProbeStreamReply = ProbeStreamReply

@typing_extensions.final
class ProbeStreamReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""
    sequence: builtins.int
    """"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        sequence: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mid", b"mid", "sequence", b"sequence"]) -> None: ...

global___ProbeStreamReq = ProbeStreamReq

@typing_extensions.final
class ProbeSubReply(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_ID_FIELD_NUMBER: builtins.int
    message_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        message_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_id", b"message_id"]) -> None: ...

global___ProbeSubReply = ProbeSubReply

@typing_extensions.final
class ProbeSubReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUVID_FIELD_NUMBER: builtins.int
    buvid: builtins.str
    """"""
    def __init__(
        self,
        *,
        buvid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buvid", b"buvid"]) -> None: ...

global___ProbeSubReq = ProbeSubReq

@typing_extensions.final
class SimpleMessage(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NUM_FIELD_NUMBER: builtins.int
    LANG_FIELD_NUMBER: builtins.int
    CATE_FIELD_NUMBER: builtins.int
    EMBEDDED_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""
    num: builtins.int
    """"""
    lang: builtins.str
    """"""
    cate: builtins.int
    """"""
    @property
    def embedded(self) -> global___Embedded:
        """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        num: builtins.int = ...,
        lang: builtins.str = ...,
        cate: builtins.int = ...,
        embedded: global___Embedded | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["embedded", b"embedded"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cate", b"cate", "embedded", b"embedded", "id", b"id", "lang", b"lang", "num", b"num"]) -> None: ...

global___SimpleMessage = SimpleMessage

@typing_extensions.final
class Task(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    CACHE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    author: builtins.str
    """"""
    cache: builtins.bool
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        author: builtins.str = ...,
        cache: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["author", b"author", "cache", b"cache", "name", b"name"]) -> None: ...

global___Task = Task



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/polymer/community/govern/v1/govern.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1bilibili/polymer/community/govern/v1/govern.proto\x12\x1e\x62ilibili.polymer.app.govern.v1\"Z\n\x12\x41ntiHarassmentInfo\x12\r\n\x05limit\x18\x01 \x01(\x05\x12 \n\x18\x66ollow_time_limit_second\x18\x02 \x01(\x05\x12\x13\n\x0b\x65xpire_time\x18\x03 \x01(\x03\"\xe9\x03\n\x15\x41ntiHarassmentSetting\x12\x0b\n\x03mid\x18\x01 \x01(\x03\x12\x12\n\nauto_limit\x18\x02 \x01(\x08\x12>\n\x02im\x18\x03 \x01(\x0b\x32\x32.bilibili.polymer.app.govern.v1.AntiHarassmentInfo\x12\x41\n\x05reply\x18\x04 \x01(\x0b\x32\x32.bilibili.polymer.app.govern.v1.AntiHarassmentInfo\x12>\n\x02\x64m\x18\x05 \x01(\x0b\x32\x32.bilibili.polymer.app.govern.v1.AntiHarassmentInfo\x12\x44\n\x08reply_me\x18\x06 \x01(\x0b\x32\x32.bilibili.polymer.app.govern.v1.AntiHarassmentInfo\x12\x43\n\x07like_me\x18\x07 \x01(\x0b\x32\x32.bilibili.polymer.app.govern.v1.AntiHarassmentInfo\x12\x41\n\x05\x61t_me\x18\x08 \x01(\x0b\x32\x32.bilibili.polymer.app.govern.v1.AntiHarassmentInfo\x12\x1e\n\x16\x61uto_limit_expire_time\x18\t \x01(\x03\"U\n\x1dLoadAntiHarassmentSettingsReq\x12\x10\n\x08\x62iz_type\x18\x01 \x01(\x05\x12\x10\n\x08recv_mid\x18\x02 \x01(\x03\x12\x10\n\x08send_mid\x18\x03 \x01(\x03\"\xa9\x01\n\x1dLoadAntiHarassmentSettingsRsp\x12\x1b\n\x13\x61nti_harassment_ret\x18\x01 \x01(\x08\x12V\n\x17\x61nti_harassment_setting\x18\x02 \x01(\x0b\x32\x35.bilibili.polymer.app.govern.v1.AntiHarassmentSetting\x12\x13\n\x0bshow_window\x18\x03 \x01(\x05\"\x97\x01\n\x1eStoreAntiHarassmentSettingsReq\x12\x10\n\x08\x62iz_type\x18\x01 \x01(\x05\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12V\n\x17\x61nti_harassment_setting\x18\x03 \x01(\x0b\x32\x35.bilibili.polymer.app.govern.v1.AntiHarassmentSetting\" \n\x1eStoreAntiHarassmentSettingsRsp*k\n\x13\x41ntiHarassmentLimit\x12\x10\n\x0c\x44\x65\x66\x61ultLimit\x10\x00\x12\x0f\n\x0b\x46ollowLimit\x10\x01\x12\x11\n\rReFollowLimit\x10\x02\x12\x10\n\x0cTwoWayFollow\x10\x03\x12\x0c\n\x08\x41llLimit\x10\x04*[\n\x07\x42izType\x12\x12\n\x0eInvalidBizType\x10\x00\x12\x06\n\x02Im\x10\x01\x12\x06\n\x02\x44m\x10\x02\x12\t\n\x05Reply\x10\x03\x12\x0b\n\x07ReplyMe\x10\x04\x12\n\n\x06LikeMe\x10\x05\x12\x08\n\x04\x41tMe\x10\x06\x32\xd4\x02\n\x15\x41ntiHarassmentService\x12\x9d\x01\n\x1bStoreAntiHarassmentSettings\x12>.bilibili.polymer.app.govern.v1.StoreAntiHarassmentSettingsReq\x1a>.bilibili.polymer.app.govern.v1.StoreAntiHarassmentSettingsRsp\x12\x9a\x01\n\x1aLoadAntiHarassmentSettings\x12=.bilibili.polymer.app.govern.v1.LoadAntiHarassmentSettingsReq\x1a=.bilibili.polymer.app.govern.v1.LoadAntiHarassmentSettingsRspb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.polymer.community.govern.v1.govern_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ANTIHARASSMENTLIMIT']._serialized_start=1116
  _globals['_ANTIHARASSMENTLIMIT']._serialized_end=1223
  _globals['_BIZTYPE']._serialized_start=1225
  _globals['_BIZTYPE']._serialized_end=1316
  _globals['_ANTIHARASSMENTINFO']._serialized_start=85
  _globals['_ANTIHARASSMENTINFO']._serialized_end=175
  _globals['_ANTIHARASSMENTSETTING']._serialized_start=178
  _globals['_ANTIHARASSMENTSETTING']._serialized_end=667
  _globals['_LOADANTIHARASSMENTSETTINGSREQ']._serialized_start=669
  _globals['_LOADANTIHARASSMENTSETTINGSREQ']._serialized_end=754
  _globals['_LOADANTIHARASSMENTSETTINGSRSP']._serialized_start=757
  _globals['_LOADANTIHARASSMENTSETTINGSRSP']._serialized_end=926
  _globals['_STOREANTIHARASSMENTSETTINGSREQ']._serialized_start=929
  _globals['_STOREANTIHARASSMENTSETTINGSREQ']._serialized_end=1080
  _globals['_STOREANTIHARASSMENTSETTINGSRSP']._serialized_start=1082
  _globals['_STOREANTIHARASSMENTSETTINGSRSP']._serialized_end=1114
  _globals['_ANTIHARASSMENTSERVICE']._serialized_start=1319
  _globals['_ANTIHARASSMENTSERVICE']._serialized_end=1659
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/broadcast/message/fission/notify.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/bilibili/broadcast/message/fission/notify.proto\x12\"bilibili.broadcast.message.fission\x1a\x1bgoogle/protobuf/empty.proto\"-\n\x0fGameNotifyReply\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t2f\n\x07\x46ission\x12[\n\nGameNotify\x12\x16.google.protobuf.Empty\x1a\x33.bilibili.broadcast.message.fission.GameNotifyReply0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.broadcast.message.fission.notify_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GAMENOTIFYREPLY']._serialized_start=116
  _globals['_GAMENOTIFYREPLY']._serialized_end=161
  _globals['_FISSION']._serialized_start=163
  _globals['_FISSION']._serialized_end=265
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilireq.grpc.protos.bilibili/polymer/contract/v1/contract.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+bilibili/polymer/contract/v1/contract.proto\x12\x1c\x62ilibili.polymer.contract.v1\x1a\x1bgoogle/protobuf/empty.proto\"g\n\x10\x41\x64\x64\x43ontractReply\x12\x15\n\rallow_message\x18\x01 \x01(\x08\x12\x13\n\x0b\x61llow_reply\x18\x02 \x01(\x08\x12\x12\n\ninput_text\x18\x03 \x01(\t\x12\x13\n\x0binput_title\x18\x04 \x01(\t\"\x83\x01\n\x0e\x41\x64\x64\x43ontractReq\x12\x37\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\'.bilibili.polymer.contract.v1.CommonReq\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0e\n\x06up_mid\x18\x03 \x01(\x03\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0e\n\x06source\x18\x05 \x01(\x05\"x\n\tCommonReq\x12\x10\n\x08platform\x18\x01 \x01(\t\x12\r\n\x05\x62uild\x18\x02 \x01(\x05\x12\r\n\x05\x62uvid\x18\x03 \x01(\t\x12\x10\n\x08mobi_app\x18\x04 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x05 \x01(\t\x12\n\n\x02ip\x18\x06 \x01(\t\x12\r\n\x05spmid\x18\x07 \x01(\t\"0\n\x0c\x43ontractCard\x12\r\n\x05title\x18\x01 \x01(\t\x12\x11\n\tsub_title\x18\x02 \x01(\t\"\x8e\x01\n\x13\x43ontractConfigReply\x12\x19\n\x11is_follow_display\x18\x01 \x01(\x05\x12\x19\n\x11is_triple_display\x18\x02 \x01(\x05\x12\x41\n\rcontract_card\x18\x03 \x01(\x0b\x32*.bilibili.polymer.contract.v1.ContractCard\"\x86\x01\n\x11\x43ontractConfigReq\x12\x37\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\'.bilibili.polymer.contract.v1.CommonReq\x12\x0b\n\x03mid\x18\x02 \x01(\x03\x12\x0e\n\x06up_mid\x18\x03 \x01(\x03\x12\x0b\n\x03\x61id\x18\x04 \x01(\x03\x12\x0e\n\x06source\x18\x05 \x01(\x05\x32\xc4\x02\n\x08\x43ontract\x12S\n\x0b\x41\x64\x64\x43ontract\x12,.bilibili.polymer.contract.v1.AddContractReq\x1a\x16.google.protobuf.Empty\x12m\n\rAddContractV2\x12,.bilibili.polymer.contract.v1.AddContractReq\x1a..bilibili.polymer.contract.v1.AddContractReply\x12t\n\x0e\x43ontractConfig\x12/.bilibili.polymer.contract.v1.ContractConfigReq\x1a\x31.bilibili.polymer.contract.v1.ContractConfigReplyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bilibili.polymer.contract.v1.contract_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_ADDCONTRACTREPLY']._serialized_start=106
  _globals['_ADDCONTRACTREPLY']._serialized_end=209
  _globals['_ADDCONTRACTREQ']._serialized_start=212
  _globals['_ADDCONTRACTREQ']._serialized_end=343
  _globals['_COMMONREQ']._serialized_start=345
  _globals['_COMMONREQ']._serialized_end=465
  _globals['_CONTRACTCARD']._serialized_start=467
  _globals['_CONTRACTCARD']._serialized_end=515
  _globals['_CONTRACTCONFIGREPLY']._serialized_start=518
  _globals['_CONTRACTCONFIGREPLY']._serialized_end=660
  _globals['_CONTRACTCONFIGREQ']._serialized_start=663
  _globals['_CONTRACTCONFIGREQ']._serialized_end=797
  _globals['_CONTRACT']._serialized_start=800
  _globals['_CONTRACT']._serialized_end=1124
# @@protoc_insertion_point(module_scope)
